@@ -196,7 +196,7 @@ class PauseMenuWidgetSet(MyWidgetSet):
     __HELP_TEXTS = (
         [
             "Game",
-            "Move", "Fight",
+            "Controls", "Fight",
             "Riddle", "Shop",
             "Boss Fight", "Pause",
             "Options",
@@ -211,7 +211,7 @@ class PauseMenuWidgetSet(MyWidgetSet):
     )
 
     def __init__(self, controls: Controls, render: Callable[[List[Renderable]], None], logger, root: py_cui.PyCUI,
-                 continue_callback: "()", exit_run_callback: "()"):
+                 continue_callback: Callable[[], None], exit_run_callback: Callable[[], None]):
         super().__init__(controls, logger, root, render)
         self.__continue_callback = continue_callback
         self.__exit_run = exit_run_callback
@@ -224,8 +224,8 @@ class PauseMenuWidgetSet(MyWidgetSet):
         choices = self.add_block_label('Choices', 1, 0, row_span= MyWidgetSet.NUM_OF_ROWS-1, column_span=3, center=True)
         self.__choices = SelectionWidget(choices, controls, stay_selected=True)
         self.__choices.set_data(data=(
-            ["Continue", "Options", "Help", "Exit"],
-            [self.__continue, self.__options, self.__help, self.__exit]
+            ["Continue", "Manual", "Options", "Exit"],
+            [self.__continue, self.__help, self.__options, self.__exit]
         ))
 
         details = self.add_block_label('Details', 1, 3, row_span=MyWidgetSet.NUM_OF_ROWS-1,
@@ -554,10 +554,13 @@ class ReachTargetWidgetSet(MyWidgetSet, ABC):
             self.__cur_instruction = self._robot.get_instruction(index)
             if self.__cur_instruction is not None:
                 if self.__cur_instruction.is_used():
-                    self._robot.remove_instruction(index)
-                    self.details.update_text(self._robot.backpack.get(index).selection_str(), index)
+                    options = [f"Position {i}" for i in range(self._robot.circuit_space)] + ["Remove"]
+                    self.details.set_data(data=(
+                        SelectionWidget.wrap_in_hotkey_str(options),
+                        [self.__choose_position]
+                    ))
                 else:
-                    if self._robot.is_space_left():
+                    if self._robot.is_space_left:
                         options = [self.__cur_instruction.preview_str(i) for i in range(self._robot.num_of_qubits)]
                         self.details.set_data(data=(
                             SelectionWidget.wrap_in_hotkey_str(options),
@@ -577,7 +580,7 @@ class ReachTargetWidgetSet(MyWidgetSet, ABC):
         selection = list(range(self._robot.num_of_qubits))
         for q in self.__cur_instruction.qargs_iter():
             selection.remove(q)
-        if self.__cur_instruction.use_qubit(selection[index]):
+        if len(selection) > index and self.__cur_instruction.use_qubit(selection[index]):
             selection.pop(index)
             options = [self.__cur_instruction.preview_str(i) for i in selection]
             self.details.set_data(data=(
@@ -585,15 +588,25 @@ class ReachTargetWidgetSet(MyWidgetSet, ABC):
                 [self.__choose_qubit]
             ))
         else:
-            self._robot.use_instruction(self.__cur_instruction)
-            options = [instruction.selection_str() for instruction in self._robot.backpack]
+            options = [f"Position {i}" for i in range(self._robot.circuit_space)] + ["Remove"]
             self._details.set_data(data=(
-                SelectionWidget.wrap_in_hotkey_str(options) + [MyWidgetSet.BACK_STRING],
-                [self.__choose_instruction]
+                SelectionWidget.wrap_in_hotkey_str(options),# + [MyWidgetSet.BACK_STRING],
+                [self.__choose_position]
             ))
         self.render()
         return False
 
+    def __choose_position(self, index: int = 0):
+        if not self._robot.use_instruction(self.__cur_instruction, index):
+            CommonPopups.NoCircuitSpace.show()
+        options = [instruction.selection_str() for instruction in self._robot.backpack]
+        self._details.set_data(data=(
+            SelectionWidget.wrap_in_hotkey_str(options) + [MyWidgetSet.BACK_STRING],
+            [self.__choose_instruction]
+        ))
+        self.render()
+        return False
+
     def __choices_commit(self) -> bool:
         if self._target is None:
             from qrogue.util.logger import Logger
@@ -616,7 +629,7 @@ class ReachTargetWidgetSet(MyWidgetSet, ABC):
             return self._on_commit_fail()
 
     def __choices_reset(self) -> bool:
-        if self._robot.has_empty_circuit():
+        if self._robot.has_empty_circuit:
             self._details.set_data(data=(
                 ["Nothing to reset"],
                 [self._empty_callback]
@@ -732,7 +745,7 @@ class FightWidgetSet(ReachTargetWidgetSet):
             ))
         else:
             self._details.set_data(data=(
-                [f"Wrong, you took {damage_taken} damage. Remaining HP = {self._robot.cur_hp}"],
+                [f"Wrong, you took {damage_taken} damage. Remaining energy = {self._robot.cur_energy}"],
                 [self._empty_callback]
             ))
         return True
